@@ -10,7 +10,7 @@
 #include "kfilterbase.h"
 
 /**
- * Internal class used by KFilterDev
+ * Internal class used by KCompressionDevice
  *
  * This header is not installed.
  *
@@ -20,7 +20,7 @@ class KGzipFilter : public KFilterBase
 {
 public:
     KGzipFilter();
-    virtual ~KGzipFilter();
+    ~KGzipFilter() override;
 
     bool init(int mode) override;
 
@@ -30,7 +30,7 @@ public:
     // - Gzip header, implemented here by readHeader
     //
     // (1) as written out by compress()/compress2()
-    // (2) see http://www.zlib.net/zlib_faq.html#faq39
+    // (2) see https://www.zlib.net/zlib_faq.html#faq39
     enum Flag {
         RawDeflate = 0, // raw deflate data
         ZlibHeader = 1, // zlib headers (HTTP deflate)
