@@ -30,7 +30,7 @@ public:
 /**
  * A KRccFileEntry represents a file in a rcc archive.
  */
-class KARCHIVE_EXPORT KRccFileEntry : public KArchiveFile
+class KRccFileEntry : public KArchiveFile
 {
 public:
     KRccFileEntry(KArchive *archive,
